@@ -1,7 +1,6 @@
 from django.conf import settings
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
-from django.contrib.sites.models import Site
+from django.utils.translation import gettext_lazy as _
 from django.utils.text import slugify
 from django.templatetags.static import static
 
